@@ -84,7 +84,7 @@
 #define KSYNTAXHIGHLIGHTING_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED
-#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KSYNTAXHIGHLIGHTING_NO_DEPRECATED_WARNINGS
 #  define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE KSYNTAXHIGHLIGHTING_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define KSYNTAXHIGHLIGHTING_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
